/// <reference types="node" />
import { VirgilPublicKey } from '../VirgilPublicKey';
import { VirgilStreamCipherBase } from './VirgilStreamCipherBase';
import { Data } from './../interfaces';
import { StringEncoding } from '../utils/anyToBuffer';
/**
 * `VirgilStreamCipher` constructor `options` parameter.
 */
export interface VirgilStreamCipherOptions {
    /**
     *  Optionally add a signature of plain data to the encrypted stream.
     */
    signature?: Data;
    /**
     * If `signature` is a string,
     * specifies its encoding, otherwise is ignored. Default is 'base64'.
     */
    encoding?: StringEncoding;
}
/**
 * Class responsible for encryption of streams of data.
 */
export declare class VirgilStreamCipher extends VirgilStreamCipherBase {
    /**
     * Initializes a new instance of `VirgilStreamCipher`.
     * `VirgilStreamCipher` objects are not meant to be created with the `new`
     * operator, use {@link VirgilCrypto.createStreamCipher} to create an
     * instance.
     *
     * @internal
     *
     * @param {VirgilPublicKey|VirgilPublicKey[]} publicKeys - A single
     * {@link VirgilPublicKey} or an array of {@link VirgilPublicKey}'s to
     * to encrypt the data with.
     * @param {VirgilStreamCipherOptions} [options] - `VirgilStreamCipherOptions` object.
     */
    constructor(publicKeys: VirgilPublicKey | VirgilPublicKey[], options?: VirgilStreamCipherOptions);
    /**
     * Starts sequential encryption process following the algorithm below:
     *
     * 1. Generates random AES-256 key - KEY1
     * 2. Generates ephemeral keypair for each recipient public key
     * 3. Uses Diffie-Hellman to obtain shared secret with each recipient
     *    public key & ephemeral private key
     * 4. Computes KDF to obtain AES-256 key - KEY2 - from shared secret for
     *    each recipient
     * 5. Encrypts KEY1 with KEY2 using AES-256-CBC for each recipient
     * 6. Returns the ASN.1 structure containing the encrypted KEY2 for each
     *    recipient public key (content_info)
     *
     * The data passed to the {@link VirgilStreamCipher.update} method after
     * this method is called will be encrypted with the KEY1
     */
    start(): Buffer;
}
